==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATECLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTTEMPLATECLAUSEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATECLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATECLAUSEID_Type", propOrder = {
    "contracttemplateid",
    "clauseid"
})
public class CONTRACTTEMPLATECLAUSEID_Type {

    @XmlElement(name = "CONTRACTTEMPLATEID", required = true)
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CLAUSEID", required = true)
    protected CLAUSEID_Type clauseid;

    /**
     * Obtient la valeur de la propriété contracttemplateid.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Définit la valeur de la propriété contracttemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété clauseid.
     * 
     * @return
     *     possible object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public CLAUSEID_Type getCLAUSEID() {
        return clauseid;
    }

    /**
     * Définit la valeur de la propriété clauseid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public void setCLAUSEID(CLAUSEID_Type value) {
        this.clauseid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATECLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTTEMPLATECLAUSEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATECLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATECLAUSEID_Type", propOrder = {
    "contracttemplateid",
    "clauseid"
})
public class CONTRACTTEMPLATECLAUSEID_Type {

    @XmlElement(name = "CONTRACTTEMPLATEID", required = true)
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CLAUSEID", required = true)
    protected CLAUSEID_Type clauseid;

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the clauseid property.
     * 
     * @return
     *     possible object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public CLAUSEID_Type getCLAUSEID() {
        return clauseid;
    }

    /**
     * Sets the value of the clauseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public void setCLAUSEID(CLAUSEID_Type value) {
        this.clauseid = value;
    }

}
